@@ -9,16 +9,9 @@ from cdev import Project as cdev_project
 myProject = cdev_project.instance()
 
 
-myProject.add_mapper(
-    DefaultMapper()
-)
+myProject.add_mapper(DefaultMapper())
 
 
 myProject.add_component(
     Cdev_FileSystem_Component(os.path.join("src", "packages"), "packages_test")
 )
-
-
-
-
-
