@@ -9,13 +9,9 @@ from cdev import Project as cdev_project
 myProject = cdev_project.instance()
 
 
-myProject.add_mapper(
-    DefaultMapper()
-)
+myProject.add_mapper(DefaultMapper())
 
 
 myProject.add_component(
-    Cdev_FileSystem_Component(os.path.join("src","examples"), "power_tools")
+    Cdev_FileSystem_Component(os.path.join("src", "examples"), "power_tools")
 )
-
-
