@@ -6,12 +6,10 @@ from src.examples.config import powertool_vars
 
 logger = Logger(service="payment")
 
-@simple_function_annotation("logger_example", environment=powertool_vars)
+
+@simple_function_annotation("logger_example", environment=powertool_vars, tags={"environment": "dev", "sample_tag": "power"})
 @logger.inject_lambda_context
 def handler(event, context):
     logger.info("Collecting payment")
 
-    logger.info({
-    "operation": "collect_payment",
-    "charge_id": event['charge_id']
-    })
\ No newline at end of file
+    logger.info({"operation": "collect_payment", "charge_id": event["charge_id"]})
